Description Usage Arguments Details Value References Examples
View source: R/ols-sandwich-lm-var.R
Compute the sandwich estimator of standard errors for ordinary least squares (OLS) regression, \insertCite@see @white1980usinglsapproxunknownregfuncs and @white1980heteroskedasticconsistentcovest;textualmaars. For more details \insertCite@see also @buja2019modelsasapproximationspart1 and @buja2019modelsasapproximationspart2;textualmaars.
1 | comp_sand_var(mod_fit)
|
mod_fit |
A |
The function computes the sandwich estimator for the OLS regression
passed in mod_fit and returns a tibble with summary information
about the components of the model based on the sandwich standard errors.
A list containing the following elements: the type of estimator of
of the variance (var_type); An abbreviated string representing the
type of the estimator of the variance (var_type_abb); the summary
statistics of mod_fit based on this estimator of the variance
(e.g., standard errors and p-values) (var_summary); the assumptions
under which the estimator of the variance is consistent
(var_assumptions); the covariance matrix for the coefficients
estimates (cov_mat).
1 2 3 4 5 6 7 8 9 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.